==> vss-ui-4.141.4.tgz: package/Components/Dynamic/DynamicLink.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from 'react';
import { BaseComponent } from 'office-ui-fabric-react/lib/Utilities';
import { ObservableComponent } from '../../Components/Dynamic/ObservableComponent';
var DynamicLink = /** @class */ (function (_super) {
    tslib_1.__extends(DynamicLink, _super);
    function DynamicLink() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DynamicLink.prototype.render = function () {
        var linkProps = tslib_1.__assign({}, this.props);
        return React.createElement(ObservableComponent, tslib_1.__assign({}, linkProps, { url: this.props.url }),
            React.createElement(DynamicLinkInternal, { url: '', children: this.props.children }));
    };
    return DynamicLink;
}(BaseComponent));
export { DynamicLink };
var DynamicLinkInternal = /** @class */ (function (_super) {
    tslib_1.__extends(DynamicLinkInternal, _super);
    function DynamicLinkInternal() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DynamicLinkInternal.prototype.render = function () {
        var linkProps = tslib_1.__assign({}, this.props);
        var childElement = null;
        if (this.props.url) {
            linkProps.href = this.props.url;
        }
        delete linkProps.url;
        if (this.props.url) {
            childElement = React.createElement("a", tslib_1.__assign({}, linkProps), this.props.children);
        }
        else {
            childElement = React.createElement("span", tslib_1.__assign({}, linkProps), this.props.children);
        }
        return childElement;
    };
    return DynamicLinkInternal;
}(BaseComponent));

==> vss-ui-4.142.1.tgz: package/Components/Dynamic/DynamicLink.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from 'react';
import { BaseComponent } from 'office-ui-fabric-react/lib/Utilities';
import { Observer } from '../../Observer';
var DynamicLink = /** @class */ (function (_super) {
    tslib_1.__extends(DynamicLink, _super);
    function DynamicLink() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DynamicLink.prototype.render = function () {
        var linkProps = tslib_1.__assign({}, this.props);
        return React.createElement(Observer, tslib_1.__assign({}, linkProps, { url: this.props.url }),
            React.createElement(DynamicLinkInternal, { url: '', children: this.props.children }));
    };
    return DynamicLink;
}(BaseComponent));
export { DynamicLink };
var DynamicLinkInternal = /** @class */ (function (_super) {
    tslib_1.__extends(DynamicLinkInternal, _super);
    function DynamicLinkInternal() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DynamicLinkInternal.prototype.render = function () {
        var linkProps = tslib_1.__assign({}, this.props);
        var childElement = null;
        if (this.props.url) {
            linkProps.href = this.props.url;
        }
        delete linkProps.url;
        if (this.props.url) {
            childElement = React.createElement("a", tslib_1.__assign({}, linkProps), this.props.children);
        }
        else {
            childElement = React.createElement("span", tslib_1.__assign({}, linkProps), this.props.children);
        }
        return childElement;
    };
    return DynamicLinkInternal;
}(BaseComponent));
